==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/Ix/Ix_Ordering.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v245	((void*)startLabel+52)
#define v248	((void*)startLabel+121)
#define CT_v252	((void*)startLabel+144)
#define FN_LAMBDA239	((void*)startLabel+180)
#define CT_v255	((void*)startLabel+212)
#define CF_LAMBDA239	((void*)startLabel+220)
#define CT_v260	((void*)startLabel+260)
#define CT_v262	((void*)startLabel+308)
#define CT_v264	((void*)startLabel+372)
#define ST_v263	((void*)startLabel+404)
#define ST_v243	((void*)startLabel+427)
#define ST_v250	((void*)startLabel+458)
#define ST_v253	((void*)startLabel+487)
#define ST_v258	((void*)startLabel+528)
#define ST_v261	((void*)startLabel+557)
#define ST_v254	((void*)startLabel+590)
extern Node TM_Ix[];
extern Node FN_Prelude_46Ord_46Prelude_46Ordering_46_60_61[];
extern Node FN_Prelude_46_38_38[];
extern Node FN_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[];
extern Node FN_Prelude_46error[];
extern Node TMSUB_Ix[];
extern Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[];
extern Node FN_Ix_46_95_46rangeSize[];
extern Node CF_Ix_46Ix_46Prelude_46Ordering[];
extern Node CF_Prelude_46Ord_46Prelude_46Ordering[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v245)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46inRange[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,HEAP_CVAL_I3,HEAP_P1)
, bytes2word(0,HEAP_ARG,2,HEAP_CVAL_I3)
, bytes2word(HEAP_ARG,2,HEAP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,7,HEAP_OFF_N1)
, bytes2word(5,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 110003
, useLabel(ST_v243)
,	/* CT_v245: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46inRange[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46inRange),2)
, VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Ordering_46_60_61))
, VAPTAG(useLabel(FN_Prelude_46_38_38))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v252)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46index[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDSTACK_I16,PUSH_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(HEAP_ARG_ARG,1,2,ZAP_ARG_I1)
, bytes2word(ZAP_STACK_P1,2,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,16,0,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_I1,EVAL,NEEDHEAP_I32)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_ARG,2)
, bytes2word(ZAP_ARG_I2,EVAL,NEEDHEAP_I32,SUB_W)
,	/* v248: (byte 1) */
  bytes2word(RETURN,HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(6,HEAP_OFF_N1,2,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80003
, useLabel(ST_v250)
,	/* CT_v252: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46index[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46index),2)
, VAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46inRange))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46fromEnum))
, VAPTAG(useLabel(FN_LAMBDA239))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v255)
,	/* FN_LAMBDA239: (byte 0) */
  useLabel(TMSUB_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v254)
, 100032
, useLabel(ST_v253)
,	/* CT_v255: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA239: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA239))
, bytes2word(1,0,0,1)
, useLabel(CT_v260)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46range[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(HEAP_I1,HEAP_I2,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 60003
, useLabel(ST_v258)
,	/* CT_v260: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46range[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46range),1)
, VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo))
, bytes2word(1,0,0,1)
, useLabel(CT_v262)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46rangeSize[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 50010
, useLabel(ST_v261)
,	/* CT_v262: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46rangeSize[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46rangeSize),1)
, VAPTAG(useLabel(FN_Ix_46_95_46rangeSize))
, useLabel(CF_Ix_46Ix_46Prelude_46Ordering)
, bytes2word(0,0,0,0)
, useLabel(CT_v264)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3,HEAP_CVAL_I3)
, bytes2word(HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
, bytes2word(HEAP_CVAL_P1,7,RETURN,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,5,0)
, 50010
, useLabel(ST_v263)
,	/* CT_v264: (byte 0) */
  HW(5,0)
, 0
,};
Node CF_Ix_46Ix_46Prelude_46Ordering[] = {
  VAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering))
, useLabel(CF_Prelude_46Ord_46Prelude_46Ordering)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46inRange)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46range)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46rangeSize)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46index)
,	/* ST_v263: (byte 0) */
  bytes2word(73,120,46,73)
, bytes2word(120,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,79,114)
, bytes2word(100,101,114,105)
,	/* ST_v243: (byte 3) */
  bytes2word(110,103,0,73)
, bytes2word(120,46,73,120)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,79,114,100)
, bytes2word(101,114,105,110)
, bytes2word(103,46,105,110)
, bytes2word(82,97,110,103)
,	/* ST_v250: (byte 2) */
  bytes2word(101,0,73,120)
, bytes2word(46,73,120,46)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(79,114,100,101)
, bytes2word(114,105,110,103)
, bytes2word(46,105,110,100)
,	/* ST_v253: (byte 3) */
  bytes2word(101,120,0,73)
, bytes2word(120,46,73,120)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,79,114,100)
, bytes2word(101,114,105,110)
, bytes2word(103,46,105,110)
, bytes2word(100,101,120,58)
, bytes2word(49,48,58,51)
, bytes2word(50,45,49,48)
,	/* ST_v258: (byte 4) */
  bytes2word(58,55,49,0)
, bytes2word(73,120,46,73)
, bytes2word(120,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,79,114)
, bytes2word(100,101,114,105)
, bytes2word(110,103,46,114)
, bytes2word(97,110,103,101)
,	/* ST_v261: (byte 1) */
  bytes2word(0,73,120,46)
, bytes2word(73,120,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,79)
, bytes2word(114,100,101,114)
, bytes2word(105,110,103,46)
, bytes2word(114,97,110,103)
, bytes2word(101,83,105,122)
,	/* ST_v254: (byte 2) */
  bytes2word(101,0,73,120)
, bytes2word(46,79,114,100)
, bytes2word(101,114,105,110)
, bytes2word(103,46,105,110)
, bytes2word(100,101,120,58)
, bytes2word(32,73,110,100)
, bytes2word(101,120,32,111)
, bytes2word(117,116,32,111)
, bytes2word(102,32,114,97)
, bytes2word(110,103,101,46)
, bytes2word(0,0,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/Ix/Ix_Ordering.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v255	((void*)startLabel+52)
#define v260	((void*)startLabel+119)
#define v262	((void*)startLabel+131)
#define v256	((void*)startLabel+136)
#define CT_v266	((void*)startLabel+168)
#define FN_LAMBDA249	((void*)startLabel+212)
#define CT_v269	((void*)startLabel+244)
#define CF_LAMBDA249	((void*)startLabel+252)
#define FN_LAMBDA248	((void*)startLabel+264)
#define CT_v272	((void*)startLabel+296)
#define CF_LAMBDA248	((void*)startLabel+304)
#define CT_v277	((void*)startLabel+344)
#define CT_v279	((void*)startLabel+392)
#define CT_v281	((void*)startLabel+456)
#define ST_v280	((void*)startLabel+488)
#define ST_v253	((void*)startLabel+511)
#define ST_v264	((void*)startLabel+542)
#define ST_v270	((void*)startLabel+571)
#define ST_v267	((void*)startLabel+612)
#define ST_v275	((void*)startLabel+651)
#define ST_v278	((void*)startLabel+680)
#define ST_v271	((void*)startLabel+713)
#define ST_v268	((void*)startLabel+752)
extern Node TM_Ix[];
extern Node FN_Prelude_46Ord_46Prelude_46Ordering_46_60_61[];
extern Node FN_Prelude_46_38_38[];
extern Node FN_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[];
extern Node FN_Prelude_46error[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];
extern Node TMSUB_Ix[];
extern Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[];
extern Node FN_Ix_46_95_46rangeSize[];
extern Node CF_Ix_46Ix_46Prelude_46Ordering[];
extern Node CF_Prelude_46Ord_46Prelude_46Ordering[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v255)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46inRange[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,HEAP_CVAL_I3,HEAP_P1)
, bytes2word(0,HEAP_ARG,2,HEAP_CVAL_I3)
, bytes2word(HEAP_ARG,2,HEAP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,7,HEAP_OFF_N1)
, bytes2word(5,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 110003
, useLabel(ST_v253)
,	/* CT_v255: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46inRange[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46inRange),2)
, VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Ordering_46_60_61))
, VAPTAG(useLabel(FN_Prelude_46_38_38))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v266)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46index[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDSTACK_I16,PUSH_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(HEAP_ARG_ARG,1,2,ZAP_ARG_I1)
, bytes2word(EVAL,NEEDHEAP_I32,JUMPFALSE,16)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_I4,HEAP_I1)
, bytes2word(EVAL,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,2,ZAP_ARG_I2,EVAL)
,	/* v260: (byte 3) */
  bytes2word(NEEDHEAP_I32,SUB_W,RETURN,PUSH_HEAP)
, bytes2word(HEAP_CVAL_IN3,JUMPFALSE,9,0)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
,	/* v262: (byte 3) */
  bytes2word(HEAP_OFF_N1,2,RETURN_EVAL,POP_P1)
,	/* v256: (byte 4) */
  bytes2word(2,JUMP,2,0)
, bytes2word(HEAP_CVAL_P1,7,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(8,HEAP_OFF_N1,2,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(1,0,0)
, 80003
, useLabel(ST_v264)
,	/* CT_v266: (byte 0) */
  HW(6,2)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46index[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46index),2)
, VAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46inRange))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46fromEnum))
, VAPTAG(useLabel(FN_LAMBDA248))
, VAPTAG(useLabel(FN_Prelude_46error))
, VAPTAG(useLabel(FN_LAMBDA249))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v269)
,	/* FN_LAMBDA249: (byte 0) */
  useLabel(TMSUB_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v268)
, 80003
, useLabel(ST_v267)
,	/* CT_v269: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA249: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA249))
, bytes2word(0,0,0,0)
, useLabel(CT_v272)
,	/* FN_LAMBDA248: (byte 0) */
  useLabel(TMSUB_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v271)
, 100032
, useLabel(ST_v270)
,	/* CT_v272: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA248: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA248))
, bytes2word(1,0,0,1)
, useLabel(CT_v277)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46range[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,2,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(HEAP_I1,HEAP_I2,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 60003
, useLabel(ST_v275)
,	/* CT_v277: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46range[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46range),1)
, VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo))
, bytes2word(1,0,0,1)
, useLabel(CT_v279)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering_46rangeSize[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 50010
, useLabel(ST_v278)
,	/* CT_v279: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Ix_46Ix_46Prelude_46Ordering_46rangeSize[] = {
  CAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering_46rangeSize),1)
, VAPTAG(useLabel(FN_Ix_46_95_46rangeSize))
, useLabel(CF_Ix_46Ix_46Prelude_46Ordering)
, bytes2word(0,0,0,0)
, useLabel(CT_v281)
,};
Node FN_Ix_46Ix_46Prelude_46Ordering[] = {
  useLabel(TM_Ix)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3,HEAP_CVAL_I3)
, bytes2word(HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
, bytes2word(HEAP_CVAL_P1,7,RETURN,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,5,0)
, 50010
, useLabel(ST_v280)
,	/* CT_v281: (byte 0) */
  HW(5,0)
, 0
,};
Node CF_Ix_46Ix_46Prelude_46Ordering[] = {
  VAPTAG(useLabel(FN_Ix_46Ix_46Prelude_46Ordering))
, useLabel(CF_Prelude_46Ord_46Prelude_46Ordering)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46inRange)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46range)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46rangeSize)
, useLabel(F0_Ix_46Ix_46Prelude_46Ordering_46index)
,	/* ST_v280: (byte 0) */
  bytes2word(73,120,46,73)
, bytes2word(120,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,79,114)
, bytes2word(100,101,114,105)
,	/* ST_v253: (byte 3) */
  bytes2word(110,103,0,73)
, bytes2word(120,46,73,120)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,79,114,100)
, bytes2word(101,114,105,110)
, bytes2word(103,46,105,110)
, bytes2word(82,97,110,103)
,	/* ST_v264: (byte 2) */
  bytes2word(101,0,73,120)
, bytes2word(46,73,120,46)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(79,114,100,101)
, bytes2word(114,105,110,103)
, bytes2word(46,105,110,100)
,	/* ST_v270: (byte 3) */
  bytes2word(101,120,0,73)
, bytes2word(120,46,73,120)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,79,114,100)
, bytes2word(101,114,105,110)
, bytes2word(103,46,105,110)
, bytes2word(100,101,120,58)
, bytes2word(49,48,58,51)
, bytes2word(50,45,49,48)
,	/* ST_v267: (byte 4) */
  bytes2word(58,55,49,0)
, bytes2word(73,120,46,73)
, bytes2word(120,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,79,114)
, bytes2word(100,101,114,105)
, bytes2word(110,103,46,105)
, bytes2word(110,100,101,120)
, bytes2word(58,56,58,51)
, bytes2word(45,49,48,58)
,	/* ST_v275: (byte 3) */
  bytes2word(55,49,0,73)
, bytes2word(120,46,73,120)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,79,114,100)
, bytes2word(101,114,105,110)
, bytes2word(103,46,114,97)
,	/* ST_v278: (byte 4) */
  bytes2word(110,103,101,0)
, bytes2word(73,120,46,73)
, bytes2word(120,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,79,114)
, bytes2word(100,101,114,105)
, bytes2word(110,103,46,114)
, bytes2word(97,110,103,101)
, bytes2word(83,105,122,101)
,	/* ST_v271: (byte 1) */
  bytes2word(0,73,120,46)
, bytes2word(79,114,100,101)
, bytes2word(114,105,110,103)
, bytes2word(46,105,110,100)
, bytes2word(101,120,58,32)
, bytes2word(73,110,100,101)
, bytes2word(120,32,111,117)
, bytes2word(116,32,111,102)
, bytes2word(32,114,97,110)
,	/* ST_v268: (byte 4) */
  bytes2word(103,101,46,0)
, bytes2word(73,120,58,32)
, bytes2word(80,97,116,116)
, bytes2word(101,114,110,32)
, bytes2word(109,97,116,99)
, bytes2word(104,32,102,97)
, bytes2word(105,108,117,114)
, bytes2word(101,32,105,110)
, bytes2word(32,102,117,110)
, bytes2word(99,116,105,111)
, bytes2word(110,32,97,116)
, bytes2word(32,56,58,51)
, bytes2word(45,49,48,58)
, bytes2word(55,49,46,0)
,};
